"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convert = void 0;
const convert = (issues, version) => {
    let glIssues = issues.map((issue) => {
        if (issue.severity === 'BLOCKER') {
            issue.severity = 'Critical';
        }
        else if (issue.severity === 'CRITICAL') {
            issue.severity = 'High';
        }
        else if (issue.severity === 'MAJOR') {
            issue.severity = 'Medium';
        }
        else if (issue.severity === 'MINOR') {
            issue.severity = 'Low';
        }
        return {
            id: issue.hash,
            category: 'sast',
            message: issue.message,
            cve: '',
            severity: issue.severity,
            scanner: {
                id: 'sonarqube',
                name: 'SonarQube'
            },
            location: {
                file: issue.component,
                start_line: issue.textRange ? issue.textRange.startLine : 0,
                end_line: issue.textRange ? issue.textRange.endLine : 0
            },
            identifiers: [
                {
                    type: 'SonarQube',
                    name: issue.rule,
                    value: issue.rule,
                    url: ''
                }
            ]
        };
    });
    let glReport = {
        version: '1.0.0',
        vulnerabilities: glIssues,
        remediations: [],
        scan: {
            analyzer: {
                id: 'sonarqube',
                name: 'SonarQube Code Scan',
                url: 'https://www.sonarqube.org/',
                vendor: {
                    name: 'GitLab'
                },
                version: version
            },
            scanner: {
                id: 'sonarqube',
                name: 'SonarQube Code Scan',
                url: 'https://www.sonarqube.org/',
                vendor: {
                    name: 'GitLab'
                },
                version: version
            },
            type: 'sast',
            start_time: new Date(Date.now()).toISOString().split('.')[0],
            end_time: new Date(Date.now()).toISOString().split('.')[0],
            status: 'success'
        }
    };
    // console.log(glReport);
    return glReport;
};
exports.convert = convert;
